==> nextcloud-app-bookmarks-1%3a0.16.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/zh_CN.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "书签",
    "Add a Bookmark" : "添加书签",
    "Add folder" : "添加文件夹",
    "Select" : "选择",
    "Deselect" : "取消选择",
    "Details" : "详情",
    "Delete" : "删除",
    "Saved" : "已保存",
    "Date added" : "添加日期",
    "Link" : "链接",
    "Tags" : "标签",
    "Description" : "描述",
    "No bookmarks here." : "没有书签。",
    "Favorites" : "收藏",
    "Settings" : "设置",
    "Bookmarklet" : "小书签",
    "Add to {instanceName} " : "添加到 {instanceName}",
    "Recently added" : "最近添加",
    "Most visited" : "访问最多",
    "View mode" : "浏览模式",
    "List view" : "列表视图",
    "RSS Feed" : "RSS ",
    "Permanently remove all bookmarks from your account. There is no going back!" : "永久删除您帐户中的所有书签。此操作无法恢复！",
    "Delete all bookmarks" : "删除所有书签",
    "Open details" : "打开详情",
    "An error occurred while trying to save the bookmark." : "尝试保存书签时发生错误。",
    "Error" : "错误",
    "Uncategorized" : "未分类",
    "Error parsing the import result" : "解析导入结果时出错",
    "Import completed successfully." : "导入完全成功。",
    "Do you really want to delete all your bookmarks?" : "您确定准备好删除所有的书签吗？",
    "Set tags" : "设置标签",
    "Failed to import one bookmark, because: " : "无法导入一个书签，因为：",
    "No file provided for import" : "未提供导入文件",
    "Unsupported file type for import" : "不支持导入的文件类型",
    "A Bookmark manager for Nextcloud" : "适用于 Nextcloud 的书签管理",
    "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "本应用允许您在一个位置存储和整理您喜爱的网站，同时允许您将他们同步到您不同的设备和浏览器中。\n在这里查看第三方客户端：https://github.com/nextcloud/bookmarks#third-party-clients",
    "Add a bookmark" : "添加书签",
    "This URL is already bookmarked! Overwrite?" : "此链接已加入书签！是否覆盖？",
    "The title of the page" : "页面标题",
    "The address of the page" : "页面地址",
    "Description of the page" : "页面描述",
    "Save" : "保存",
    "Previews" : "预览",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "为了显示您书签网站的真实截图，书签应用使用第三方服务生成截图。",
    "You can either sign up for free at <a href=\"http://screeenly.com\">screeenly.com</a> or <a href=\"https://github.com/stefanzweifel/screeenly\">setup your own server</a>." : "您即可以在 <a href=\"http://screeenly.com\">screeenly.com</a> 免费注册，也可以 <a href=\"https://github.com/stefanzweifel/screeenly\">设置您自己的服务器</a>。",
    "Screenly API URL" : "Screenly API 地址",
    "Screenly API key" : "Screenly API 密钥",
    "Bookmarks feed" : "书签 Feed"
},
"nplurals=1; plural=0;");

==> nextcloud-app-bookmarks-1%3a2.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/zh_CN.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "书签",
    "Add a Bookmark" : "添加书签",
    "Add folder" : "添加文件夹",
    "Select" : "选择",
    "Deselect" : "取消选择",
    "Details" : "详情",
    "Delete" : "删除",
    "Saved" : "已保存",
    "Date added" : "添加日期",
    "Link" : "链接",
    "Tags" : "标签",
    "Description" : "描述",
    "No bookmarks here." : "没有书签。",
    "Favorites" : "收藏",
    "Settings" : "设置",
    "Bookmarklet" : "小书签",
    "Add to {instanceName} " : "添加到 {instanceName}",
    "Recently added" : "最近添加",
    "Most visited" : "访问最多",
    "View mode" : "浏览模式",
    "List view" : "列表视图",
    "RSS Feed" : "RSS ",
    "Permanently remove all bookmarks from your account. There is no going back!" : "永久删除您帐户中的所有书签。此操作无法恢复！",
    "Delete all bookmarks" : "删除所有书签",
    "Open details" : "打开详情",
    "An error occurred while trying to save the bookmark." : "尝试保存书签时发生错误。",
    "Error" : "错误",
    "Uncategorized" : "未分类",
    "Error parsing the import result" : "解析导入结果时出错",
    "Import completed successfully." : "导入完全成功。",
    "Do you really want to delete all your bookmarks?" : "您确定准备好删除所有的书签吗？",
    "Set tags" : "设置标签",
    "Not allowed to access folder to import into" : "不允许访问要导入的文件夹",
    "Failed to import one bookmark, because: " : "无法导入一个书签，因为：",
    "No file provided for import" : "未提供导入文件",
    "Unsupported file type for import" : "不支持导入的文件类型",
    "A Bookmark manager for Nextcloud" : "适用于 Nextcloud 的书签管理",
    "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "本应用允许您在一个位置存储和整理您喜爱的网站，同时允许您将他们同步到您不同的设备和浏览器中。\n在这里查看第三方客户端：https://github.com/nextcloud/bookmarks#third-party-clients",
    "Add a bookmark" : "添加书签",
    "This URL is already bookmarked! Overwrite?" : "此链接已加入书签！是否覆盖？",
    "The title of the page" : "页面标题",
    "The address of the page" : "页面地址",
    "Description of the page" : "页面描述",
    "Save" : "保存",
    "Previews" : "预览",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "为了显示您书签网站的真实截图，书签应用使用第三方服务生成截图。",
    "You can either sign up for free at <a href=\"http://screeenly.com\">screeenly.com</a> or <a href=\"https://github.com/stefanzweifel/screeenly\">setup your own server</a>." : "您即可以在 <a href=\"http://screeenly.com\">screeenly.com</a> 免费注册，也可以 <a href=\"https://github.com/stefanzweifel/screeenly\">设置您自己的服务器</a>。",
    "Screeenly API URL" : "Screenly API 地址",
    "Screeenly API key" : "Screenly API 密钥",
    "Bookmarks feed" : "书签 Feed"
},
"nplurals=1; plural=0;");
